package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(_``````````0```````
M`,&H``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*P(````````K`@`
M```````0``````$````&````````N[@```````"[N````````+NX````````
M!-`````````$^````````!```````@````8```````"[R````````+O(````
M````N\@````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````$P`````````3``````````!&1TY5``
M```$````````I0@```````"E"````````*4(`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+NX````````N[@`````
M``"[N`````````1(````````!$@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`B[NZ?39!LM2<JFWMW[46AH1.HLL````$````8,K^
M&GY&1$\`>R)T>7!E(CHB9&5B(BPB;W,B.B)U8G5N='4B+")N86UE(CHB9VQI
M8F,B+")V97)S:6]N(CHB,BXT,"TQ=6)U;G1U,R(L(F%R8VAI=&5C='5R92(Z
M(G,S.3!X(GT`````````!````&S*_AI^1D1/`'LB='EP92(Z(F1E8B(L(F]S
M(CHB=6)U;G1U(BPB;F%M92(Z(FQI8G!A<BUP86-K97(M<&5R;"(L(G9E<G-I
M;VXB.B(Q+C`V,RTQ8G5I;&0Q(BPB87)C:&ET96-T=7)E(CHB<S,Y,'@B?0``
M``````0````0`````4=.50```````````P````(`````````$0```$,````$
M````"(0$0`4`$!`@A`"&@`0``B@(!"`)`@")@@@"`+I!$("(`````````$,`
M``!&````20```$H```!2````4P```%0`````````5@```%<```!8````60``
M`%H```!<```````````?W\5N+4?>SGR:?VNVF\4N?-1DU`[D_R$<6''9`<9'
MXF^+`;+`XTNLA]?Z0BP_Y<)\DN.Z8&RA^IO#3YG60PEK9LRO9^S514+3<`>)
M[=MB,\PEC!4+ESH-FYRI?PH"I^!0GAIK2?O@HP``````````````````````
M`````````````````````P``#````````!HX``````````````-T$@``````
M``````````````````````*?$@````````````````````````````",$0``
M``````````````````````````'#$@````````````````````````````(&
M$@````````````````````````````*&$@``````````````````````````
M``"]$@````````````````````````````)"$@``````````````````````
M```````!(`````````````````````````````)_$@``````````````````
M``````````!G$@````````````````````````````&V$@``````````````
M``````````````#&$@````````````````````````````+1$@``````````
M``````````````````&%$@````````````````````````````'V$@``````
M``````````````````````$I$@````````````````````````````%J$@``
M``````````````````````````"4$@`````````````````````````````0
M(`````````````````````````````*W$@``````````````````````````
M``$@$@````````````````````````````"*$0``````````````````````
M``````$W$@`````````````````````````````L(```````````````````
M``````````"=$@````````````````````````````*I$@``````````````
M``````````````%-$@````````````````````````````#A%@``````````
M``````````````````#T$@````````````````````````````%^$@``````
M``````````````````````)5$@````````````````````````````$/$@``
M``````````````````````````+"$@````````````````````````````"S
M$@````````````````````````````!8(@``````````````````````````
M``'0$@````````````````````````````&Q$@``````````````````````
M``````$^$@````````````````````````````'*$@``````````````````
M``````````%C$@````````````````````````````&B$@``````````````
M``````````````*1$@````````````````````````````(G$@``````````
M``````````````````!Y$@````````````````````````````%W$@``````
M``````````````````````'A$@````````````````````````````"<$@``
M``````````````````````````#:$@````````````````````````````(2
M$@````````````````````````````&^$@``````````````````````````
M``)S$@````````````````````````````*D$@``````````````````````
M``````'O$@````````````````````````````)F$0``````````````````
M``````````&,$@````````````````````````````"D$@``````````````
M``````````````#,$@````````````````````````````$$$@``````````
M``````````````````%5$@````````````````````````````"K$@``````
M``````````````````````(S$@````````````````````````````!&$@``
M``````````````````````````&4$@````````````````````````````&;
M$0````````````````````````````-]$@``#@```````&!``````````-H`
M``/2$@``#@```````%4@````````"-(```!3$@``#@```````"%@````````
M`I````+T$@``#@```````$4```````````8```,2$@``#@```````%X`````
M`````D````/X$@``#@```````$40`````````[8```.X$```&````````,"(
M``````````````,%$@``#@```````$C0`````````$````,H$@``#@``````
M`%!0`````````(@```.)$0``$````````&1```````````0```.E$@``#@``
M`````&&``````````4````.P$@``#@```````$/0`````````#@```/-$```
M&````````,"P``````````````/F$@``#@```````%.0`````````9````0/
M$@``#@```````%#@`````````((```.8$```%P```````,``````````````
M``-,$@``#@```````$D0`````````9(```/?$```&````````,"(````````
M``````0%$0``%P```````,"```````````@```.>$@``#@```````"/P````
M``````````/$$@``#@```````&$@`````````%X```.:(```%P```````,``
M``````````````-B$@``#@```````%-0`````````#8```,V$@``#@``````
M`$00`````````.H```-8$@``#@```````&+``````````3P```07$@``#@``
M`````$JP````````!98`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C
M7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`
M7U]S=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C
M8V5S<P!O<&5N9&ER`')E861D:7(V-`!C;&]S961I<@!R;61I<@!?7W-P<FEN
M=&9?8VAK`'5N;&EN:P!03%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A
M9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L
M7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!R96%L;&]C`%]?;65M
M;6]V95]C:&L`9V5T<&ED`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T
M<G1O:P!S=')R8VAR`&UE;6-P>0!S=&1E<G(`7U]V9G!R:6YT9E]C:&L`97AI
M=`!L<V5E:S8T`')E860`9V5T=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`
M7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,
M7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`
M<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`;&EB<&5R;"YS;RXU+C0P`&QI8F,N
M<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N
M9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R
M+C,N,@!'3$E"0U\R+C(````````"``$``@`"``$``0`"``$``0`"``,``@`"
M``$``@`!``$`!``"``$``0`"``(``@`!``4``0`"``$``0`"``$``0`!``(`
M`@`"``(``0`"``(`!@`!``$`!@`"``8`!0`"``$``@`!``(``@`!``(``@`&
M``$`!``"``$`!P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$`!@```NH````0``````:6D;0````'
M```$)````!`-:6D4````!@``!"\````0!I:1LP````4```0Y````$`EI&70`
M```$```$1````!`):1ER`````P``!%`````0#6EI$@````(```1<````````
M`````+NX``````````P````````E$````````+O```````````P````````D
MP````````+^H``````````P```````!>`````````+_H``````````P`````
M``#`@````````+_X``````````P````````A8````````,`(``````````P`
M``````#`"````````,`@``````````P```````"DL````````,`H````````
M``P```````!DG````````,`X``````````P```````!E/````````,!`````
M``````P```````!E0````````,!(``````````P```````"DI````````,!0
M``````````P```````!DH@```````,!8``````````P```````"DK```````
M`,!H``````````P```````"DE````````,!P``````````P```````"DF@``
M`````,"```````````P```````!G)````````+^0````!`````H`````````
M`````````+^8````"0````H``````````````````+^@````"@````H`````
M`````````````+^P````%0````H``````````````````+^X````&@````H`
M`````````````````+_`````'@```#@``````````````````+_(````'P``
M``H``````````````````+_0````(0````H``````````````````+_8````
M)0````H``````````````````+_@````.`````H``````````````````+_P
M````0@````H``````````````````+W@`````@````L`````````````````
M`+WH`````P````L``````````````````+WP````!0````L`````````````
M`````+WX````!@````L``````````````````+X`````!P````L`````````
M`````````+X(````"`````L``````````````````+X0````"P````L`````
M`````````````+X8````#`````L``````````````````+X@````#0````L`
M`````````````````+XH````#@````L``````````````````+XP````#P``
M``L``````````````````+XX````$`````L``````````````````+Y`````
M$0````L``````````````````+Y(````$@````L``````````````````+Y0
M````$P````L``````````````````+Y8````%`````L`````````````````
M`+Y@````%@````L``````````````````+YH````%P````L`````````````
M`````+YP````&0````L``````````````````+YX````&P````L`````````
M`````````+Z`````'`````L``````````````````+Z(````'0````L`````
M`````````````+Z0````(`````L``````````````````+Z8````(@````L`
M`````````````````+Z@````(P````L``````````````````+ZH````)```
M``L``````````````````+ZP````)0````L``````````````````+ZX````
M)@````L``````````````````+[`````)P````L``````````````````+[(
M````*`````L``````````````````+[0````*0````L`````````````````
M`+[8````*@````L``````````````````+[@````*P````L`````````````
M`````+[H````+`````L``````````````````+[P````+0````L`````````
M`````````+[X````+@````L``````````````````+\`````+P````L`````
M`````````````+\(````,`````L``````````````````+\0````,0````L`
M`````````````````+\8````,@````L``````````````````+\@````,P``
M``L``````````````````+\H````-`````L``````````````````+\P````
M-0````L``````````````````+\X````-@````L``````````````````+]`
M````-P````L``````````````````+](````.0````L`````````````````
M`+]0````.@````L``````````````````+]8````.P````L`````````````
M`````+]@````/`````L``````````````````+]H````/0````L`````````
M`````````+]P````/@````L``````````````````+]X````/P````L`````
M`````````````+^`````0`````L``````````````````+^(````00````L`
M`````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```%&^P!```%*GXQ`0```$
MN0(`$:>$``,-X>-`\1``!.MO\-``!`?T``#C$/`X`"3`$```4:72!_`P$`CC
M$!`0``0'\0<`!P`'`,`0``!1I.,0$```!`?Q#1#C$!`,`!3`]/___^4`````
MP!```%&8XQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```48SC$!````0'
M\0T0XQ`0#``4P/3____%````,,`0``!1@.,0$```!`?Q#1#C$!`,`!3`]/__
M_[4```!(P!```%%TXQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```46CC
M$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!17.,0$```!`?Q#1#C$!`,
M`!3`]/___X4```"0P!```%%0XQ`0```$!_$-$.,0$`P`%,#T____=0```*C`
M$```443C$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!1..,0$```!`?Q
M#1#C$!`,`!3`]/___U4```#8P!```%$LXQ`0```$!_$-$.,0$`P`%,#T____
M10```/#`$```42#C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!1%.,0
M$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```%$(XQ`0```$!_$-$.,0$`P`
M%,#T____%0```3C`$```4/SC$!````0'\0T0XQ`0#``4P/3___\%```!4,`0
M``!0\.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```%#DXQ`0```$!_$-
M$.,0$`P`%,#T___^Y0```8#`$```4-CC$!````0'\0T0XQ`0#``4P/3___[5
M```!F,`0``!0S.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```%#`XQ`0
M```$!_$-$.,0$`P`%,#T___^M0```<C`$```4+3C$!````0'\0T0XQ`0#``4
MP/3___ZE```!X,`0``!0J.,0$```!`?Q#1#C$!`,`!3`]/___I4```'XP!``
M`%"<XQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```4)#C$!````0'\0T0
MXQ`0#``4P/3___YU```"*,`0``!0A.,0$```!`?Q#1#C$!`,`!3`]/___F4`
M``)`P!```%!XXQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```4&SC$!``
M``0'\0T0XQ`0#``4P/3___Y%```"<,`0``!08.,0$```!`?Q#1#C$!`,`!3`
M]/___C4```*(P!```%!4XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`$```
M4$CC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!0/.,0$```!`?Q#1#C
M$!`,`!3`]/___@4```+0P!```%`PXQ`0```$!_$-$.,0$`P`%,#T___]]0``
M`NC`$```4"3C$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!0&.,0$```
M!`?Q#1#C$!`,`!3`]/___=4```,8P!```%`,XQ`0```$!_$-$.,0$`P`%,#T
M___]Q0```S#`$```4`#C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0``!/
M].,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$_HXQ`0```$!_$-$.,0
M$`P`%,#T___]E0```WC`$```3]SC$!````0'\0T0XQ`0#``4P/3___V%```#
MD,`0``!/T.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$_$XQ`0```$
M!_$-$.,0$`P`%,#T___]90```\#`$```3[CC$!````0'\0T0XQ`0#``4P/3_
M__U5```#V,`0``!/K.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!```$^@
MXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```3Y3C$!````0'\0T0XQ`0
M#``4P/3___TE```$(,`0``!/B.,0$```!`?Q#1#C$!`,`!3`]/___14```0X
MP!```$]\XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```3W#C$!````0'
M\0T0XQ`0#``4P/3___SU```$:,`0``!/9.,0$```!`?Q#1#C$!`,`!3`]/__
M_.4```2`P!```$]8XQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```3TSC
M$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!/0.,0$```!`?Q#1#C$!`,
M`!3`]/___+4```3(P!```$\TXQ`0```$!_$-$.,0$`P`%,#T___\I0``!.#`
M$```3RCC$!````0'\0T0XQ`0#``4P/3___R5```$^```````````ZV_P,``D
MLD\`L+D$`._KNP`@``VR3P"QX_#_./]QX^#P```DXS#PJ``DXT#PH``D4"#P
MM$%`\*!!,/"HT@?PP+`H02#PM,#E____J<1(``!.]L0H``!/#[D$`#3`Y0``
M(2+$&```3P^5`!``IX0`N<`P``!.^.-0,```!%B@\+3C9;````3LF@`$`-B6
M`V2*N10`Z>LN``,`#:>J``/`Y?___NWC$/"H``3`,```3SOC`!````3C8#``
M``3C`"```"18D/"TN00`4N-@4!``),0K``!/-,!````B=>-`4!@`),`@```B
M;>,@4`@`).R<`,4!?NQ)``,`V.P)__\`V$'@$`BG*``$IP$``:=T`(*(```!
MN10`8NM&``,`#>-@X```!.P2``$`V.-D4```)+D4`#'K$P`#``WC,.`(``2G
M*@`"XS%0```DI^L`$*<&_^/LZ0`#`-C$*```3OBY%`">N10`2NNI``,`#4'J
M4`#E2.````"G:0``P#````X3P.7___P<["@`5`!^Q"@``$[>06#PO,#E___]
MX;D$`#:Y!`"2P"```"#UP.4```P[["@`1P!\Q"@``$[)P.7___O.P.7___S[
MU0?PP+`HIW0`6;D$`"GK;_#X``0'_L#E___\K<0K``!.LNPH`$X`?,#E___]
M),`P``!.->,@,```!.-"L```!)(`20:G]/\UXS#@```$IR@`!>,P4"``)$'@
M$!#L)/]V8':G]/^4Q"@``$Z-P.7___PBI_3_J<!0``!.@>,@4````J>$``?`
MY0``'DFG]/^QN00`-L`@```@<<#E```+W\0K``!.;.PH_Z0`?*?T_^VGZ``$
MI_3_;L#E___]C*<I``'`Y?___1=!0/`(XS#P```$IPG_\+F``/"G^_]0UP?P
M`/``Z^_PH``D07#PH*=I``"G60``P"```$WMXR`@```$P.7___YW```'!P<'
M!P<'!P<'!P<'!\`0``!.),`@``!.(>P2``J`9,08``!-K^P8``0`?`?Q!_X'
M!P<'!P<'!P<'!P<'!\`0``!.#,`@``!.";D)`!+K`0`#``KK,0`_``RY"``P
MZS,``0`*[#@`#0!\Q!@``$V.[!@`!P!\P"```$WP!_$'_@<'!P<'!P<'!P<'
M!P<'Z[_P6``DP+```$WAX_#_8/]QE0"P`*=T`!7`$```37_C$!````*GA``(
MQ"@``$V/P.7___QTP.7___^ED@&P`.N_\/@`!`?^!P<'!P<'!P?`]/___[`'
M!P<'!P<'!P<'ZV_P,``DLD\`L+D$`._C\/S0_W'CX/```"3KZP`@``VR3P#A
MYV`/#P!$0:#PJ-('\RC@*+D$`!I!4"`XN00`.J=)``3G`%``,`:G6P`0YR``
M(#`XYQ!@``!HYT(0`#!AYS(0`#!@YT`P`#`.YS`P$#`.ISL`(*='_^?GP*`0
M.`;GX*`@.`;G(*`P.`;G4`\/`$2G"0`@YP`0:#@&YW(```16YR`00#@&YT`0
M`#@&IQL`$.=B```.;><60``.;><QP``.;>=3`!\\..=S``$\,.>%<``.:N>H
M4``,:.>@$'`X#N?.```,5N?G```(5J<'_]3CL"`(``3CH"`0``3CT"`8``3C
M4"````3CT/"@`"3C,/"H``2YY]!*N8``2[F"`$WL=2"_)5G".EJ">9GL=2`Z
M!5;C,"`@``CC@/"P``2Y"`!SXP#PN``$N0@`=.-`\,``!,**6H)YF<)*6H)Y
MF;D(`(W""EJ">9FY"``*ZVL``@`,ZS4``@`,[&L`(1Y6[#4`(1Y6[)8@OP!5
MN8(`8[GGD!JY@``5N8(`&KD(`!CLAR"_`%6Y@`!HN8(`:;D(`&"YZ)`$XT#P
MR``$[-<[OR59PDI:@GF9[-@`.@56N0@`'>QQ(+\`5>P1.[\E6>P7`#H%5KD(
M`!;KF``"``SL8R"_`%7LF``A'E;LT3N_)5GL@2"_`%6Y@@`YN>1P$[F"`!:Y
M"``0N>A@!.-`\-``!+D$`#W"2EJ">9GL.``Z!5:Y"``3[&D@OP!5[-$[OR59
MZS<``@`,[#<`(1Y6['$@OP!5N8(`D^?0#P\(1+GD@!FY@@`6N0@`$+GH8`3C
M0/#8``2Y!`"=PDI:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8``(`#.R8
M`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!"YZ&`$XT#PX``$N00`/<)*6H)Y
MF>PX`#H%5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3
MN>2`&;F"`!:Y"``0N>A@!.-`\.@`!+D$`)W"2EJ">9GLEP`Z!5:Y"``9[&,@
MOP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`$+GH
M8`3C0/#P``2Y!``]PDI:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E6>LW``(`
M#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!"YZ&`$XT#P^``$N00`G<)*
M6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L@2"_`%6Y
M@@`YN>1P$[F"`!:Y"``0N>A@!.-`\0``!+D$`#W"2EJ">9GL.``Z!5:Y"``3
M[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY@@`6N0@`
M$+GH8`3C0/$(``2Y!`"=PDI:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8
M``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!"YZ&`$XT#Q$``$N00`
M/<)*6H)YF>PX`#H%5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_
M`%6Y@@"3N>2`&;F"`!:Y"``0N>A@!.-`\1@`!+D$`)W"2EJ">9GLEP`Z!5:Y
M"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6
MN0@`$+GH8`3C0/$@``2Y!``][#@`.@56[&D@OP!5N0@`$\)*6H)YF>LW``(`
M#.PW`"$>5KF"`)/L<2"_`%7LT3N_)5FYY(`9N00`G;F"`!;LEP`Z!5:Y"``0
MN>A@!.-`\2@`!+D(`!GL8R"_`%7KF``"``SLF``A'E:Y@@`Y[($@OP!5[-$[
MOR59PDI:@GF9N>1P$[D$`#WL.``Z!5:Y@@`6N0@`$+GH8`2Y"``3[&D@OP!5
MZS<``@`,XT#Q,``$[#<`(1Y6N8(`D^QQ(+\`5>S1.[\E6;GD@!FY!`"=[)<`
M.@56N8(`%L)*6H)YF;D(`!"YZ&`$N0@`&>QC(+\`5>N8``(`#.R8`"$>5KF"
M`#GL@2"_`%7LT3N_)5GC0/$X``2YY'`3N00`/>PX`#H%5KF"`!:Y"``0N0@`
M$^LW``(`#.PW`"$>5N-P\4``!,)*6H)YF;GH8`3L:2"_`%7">EJ">9FY@@"3
MN>A@1[F``)CLT3N_)5FY@@"6[-$@.@56ZV@``@`,P!H`````[&@`(1Y6XX#Q
M2``$[',@OP!5N0@`D+F"`#:Y"`"=N8``,>P).[\E6;F"`#?L"2`Z!5:Y"``T
MZT$``@`,N0@`,.Q!`"$>5NP3.[\E6>P3(#H%5KGG0-;"BF[9ZZ&Y@@#9N0@`
M>+D:`'VY"`!QXQ#Q6``$XP#Q4``$[-DBOSY9PAINV>NA[-D"(1Y6N1H`%+GG
MT(3L0R*_/EFY@@"#[$,"(1Y6N>=`/;F"`#?""F[9ZZ&Y&@`3N1H`!N,P\6@`
M!+D$`)"Y&@"8XX#Q8``$[&<[OR59[&<@.@56N0@`EL**;MGKH>QI.[\E6;D:
M`(WL:2`Z!5;LUR*_/EFY"``6[-<"(1Y6PCINV>NAN>?0=+D:`#2Y@@!Y[$DB
MOSY9[$D"(1Y6N>=`G;F"`)'L`3N_)5FY&@`Y[`$@.@56XY#Q<``$N1H`A^QA
M(K\^6;D(`(#L80(A'E;L"#N_)5GC$/%X``3L""`Z!5:Y"``PPIINV>NAN>=@
M=,(:;MGKH;F"`'BY&@`4[$@BOSY9[$@"(1Y6XX#Q@``$N1H`G<**;MGKH;D:
M`)>Y&@"&N>=`=NS3.[\E6;F"`'/LTR`Z!5:Y&@`7N0@`G>QC(K\^6>P).[\E
M6>QC`B$>5NP)(#H%5KD(`!#L,3N_)5GL,2`Z!5:SP0!3XS#QB``$N>=@!,(Z
M;MGKH;F"``FY&@`T['DBOSY9L\T`1>QY`B$>5N.0\9``!+D:`(#"FF[9ZZ&Y
M"`"$N>=P!KD:`):Y@@`![-@[OR59N1H`,.S8(#H%5NQA(K\^6;D(`#WL80(A
M'E;L$SN_)5GL$R`Z!5:YYV#7XT#QF``$N8(`V+D:`)VY"`"1[!@BOSY9[!@"
M(1Y6XX#QH``$N><0UL)*;MGKH;F"`-.Y&@!'[`D[OR59N1H`3>P)(#H%5L**
M;MGKH;D(`$"Y&@"&[&,BOSY9[&,"(1Y6[#0[OR59[#0@.@56L\$`(^,P\:@`
M!+GG8`'".F[9ZZ&Y@@`)N1H`,>QY(K\^6;/-`!+L>0(A'E;CD/&P``2Y&@"`
MPIINV>NAN0@`@;GG<`:Y&@"6[-@[OR59[-@@.@56L\$`';/-`&&Y@@`$[-0B
MOSY9N1H`,.S4`B$>5KD(`#:YY]`'[$,[OR59N8(`".Q#(#H%5KD:`)"Y"`"4
M[&D[OR59[&D@.@56XQ#QN``$L\$`-N-@\<``!+/-``/"&F[9ZZ'L2"*_/EFY
M&@`7[$@"(1Y6PFINV>NAN>=`C;D:`&VY@@"#[-,BOSY9N1H`&.S3`B$>5KD(
M`!#L,3N_)5GL,2`Z!5:SP0!3XS#QR``$N>?0=,(Z;MGKH;D:`#2SS0!%N8(`
M>>R)(K\^6;D:`&?LB0(A'E:Y"`!DN>>`G>P&.[\E6;F"`)'L!B`Z!5:Y&@`Y
M[$$BOSY9N0@`,.Q!`B$>5NP3.[\E6>P3(#H%5K/!`&'C$/'8``2YYT`(PAIN
MV>NAXW#QT``$N1H`&+/-`(:Y@@`&PGINV>NAN1H`?;D:`'"Y"`!X[(<@OP!5
M[)<[OR59[)@`.@56[-8BOSY9XP#QZ``$[-8"(1Y6N>?09+F"`&.Y&@`6N0@`
M&>.0\>``!.QC(K\^6<*:;MGKH>QC`B$>5KD:`)2YYV`][$$[OR59N8(`-\(*
MCQN\W.QQ(+\`5;D:``WK&``"``SL&``A'E;LT2"_`%6YY-"&[$<`.@56N1H`
MD[GF$#:Y@``WN8$`...`\?``!+D(`)2Y"``P[$D@OP!5XP#Q^``$[)D[OR59
M[)0`.@56PHJ/&[S<N0@`.;D:`(;KEP`"``SLEP`A'E:YY-!YN8$`&;F``!2Y
M@0`7N0@`&.QC(+\`5<(*CQN\W.PS.[\E6;D(``WL-@`Z!5:Y"``QZQ0``@`,
M[!0`(1Y6[-$@OP!5N>30B;GF$$FY@`!&N8$`2.R#(+\`5;D(`$#C`/(```3L
M,SN_)5GL.``Z!5:Y"``T[',@OP!5[$,[OR59XS#R"``$P@J/&[S<N1H`">N6
M``(`#.R6`"$>5KGDT&FY@0`9N8``&+F!`!:Y"``0[$<`.@56PCJ/&[S<N0@`
M0;GHT`/K&``"``SL&``A'E;LT2"_`%6YY-")N>80:;F``&>Y@0!H[(0@OP!5
MN0@`8.Q$.[\E6>,`\A``!.Q(`#H%5KD(`$;L9""_`%7L-#N_)5GC0/(8``3"
M"H\;O-RY&@`)PDJ/&[S<ZY<``@`,[)<`(1Y6N>30>;F!`!FY@``8N8$`%[D(
M`!"YZ-`$[#8`.@56N0@`,>L8``(`#.P8`"$>5NS1(+\`5;GF$(FYY-!YN8``
MAKF!`(?C</(H``2Y"`"`XP#R(``$[$,@OP!5P@J/&[S<N1H`"<)ZCQN\W.PS
M.[\E6>PT`#H%5KD(`#CKA@`"``SLA@`A'E:YY-!HN8$`&+F``!2Y@0`6N0@`
M$+GHT`?LDR"_`%7L,SN_)5GL.0`Z!5:Y"``QZQ0``@`,[',@OP!5[!0`(1Y6
M[#,[OR59[-$@OP!5N>802+GDT&BY@`!)[#<`.@56N8$`1KD(`$#C`/(P``2Y
M"``T[$,@OP!5[&,[OR59XS#R.``$P@J/&[S<N1H`".N)``(`#.R)`"$>5KGF
M@)&YY-`8[&0`.@56N8``E\(ZCQN\W+F!`)&Y"``]L\$`([D(`)"SS0`"N0@`
MENL7``(`#.P7`"$>5NS1(+\`5;GDT'BYYA`X[&D[OR59N8``-+F!`#?L>2"_
M`%7CD/)```3L9P`Z!5:Y"``PPIJ/&[S<N0@`-K/!`!FSS0!AZY0``@`,N1H`
M:.R4`"$>5NQ#(+\`5;GDT`FY@0`9N8``%[F!`!"Y"``6XV#R2``$[#,[OR59
MPFJ/&[S<N>C0!NPT`#H%5KD(`#'K%P`"``SL%P`A'E;LT2"_`%6YYA!YN>30
MB;F``'2Y@0!XN0@`<.,`\E``!.R#(+\`5<(*CQN\W.PS.[\E6;D:``GL.``Z
M!5:YZ#"7ZS0``@`,['D@OP!5[#0`(1Y6[$D[OR59XY#R6``$N>308[F!`!/"
MFH\;O-RY@``8N8$`%KD(`!"YZ-`)[$<`.@56N0@`0>L8``(`#.P8`"$>5NS1
M(+\`5;GF$&.YY-"#N8``9[F!`&BY"`!@XP#R8``$[(0@OP!5P@J/&[S<[$0[
MOR59N1H``^Q(`#H%5KGH0#;L8R"_`%7L0SN_)5GC,/)H``3KEP`"``S".H\;
MO-SLEP`A'E:YY-!YN8$`&;F``!BY@0`7N0@`$+GHT`/C,/)P``3L1@`Z!5:Y
M"`!!ZQ@``@`,[!@`(1Y6['$@OP!5N>1PB;GF$-G".H\;O-RY@`#6N1H`.;F!
M`-CKE@`"``SLA""_`%7LE@`A'E:Y"`#0[$0[OR59[$@`.@56N0@`3>QD.[\E
M6>S4(+\`5;GFD$&Y!``6XV#R>``$N>1P">P=`#H%5KF``$C":H\;O-RY@0!`
MN0@`0[GH<#:Y"`!!ZQ@``@`,[!@`(1Y6['$@OP!5N>80B;GD<&FY@`"-N8$`
MAKD(`(/C,/*```3L!#N_)5G".H\;O-SL!"`Z!5:Y&@`YL\$``[D(`(#K;0`"
M``SC,/*(``2Y!`"6[)T`(1Y6N>1P";/-`&#`2@````"Y@0`9N8``%+F!`!#C
M`/*0``3".LIBP=:YZ'!SN0@`%NS8.[\E6;/!`"?LV"`Z!5;K=``"``S""LIB
MP=;L=``A'E:Y&@`)N>=P2;/!`$"Y@@!([&@BOSY9L\T`,NQH`B$>5K/-`(2Y
M"``=[-$[OR59[-$@.@56N1H`-+D(`#VYYV#7[$,[OR59N8(`T>Q#(#H%5KD:
M`(VY"`"$[)@[OR59[)@@.@56XP#RF``$L\$`6>.0\J``!+/-`-7""LIBP=;"
MFLIBP=:Y&@`'N1H`ENQQ(K\^6>QQ`B$>5KD$`!"YYW!&[&,BOSY9N8(`0^QC
M`B$>5KD:`!2Y"``=[#$[OR59[#$@.@56N>=@!^-`\J@`!+F"``BY&@"0N0@`
MD^PX(K\^6>PX`B$>5N.`\K``!+GG,`;"2LIBP=:Y@@`!N1H`1^S9.[\E6;D:
M`$#LV2`Z!5;"BLIBP=:Y"`!-N1H`ANQA(K\^6>QA`B$>5NP4.[\E6>P4(#H%
M5K/!``'C$/*X``2YYV#3PAK*8L'6N8(`V;D:`!/L>2*_/EFSS0`P['D"(1Y6
MXY#RP``$N1H`C<*:RF+!UKD(`(.YYW#6N1H`EKF"`-3C,/+(``2Y&@`=[`@[
MOR59[&0BOSY9[`@@.@56[&0"(1Y6N0@`$.Q!.[\E6>Q!(#H%5KGG8`>Y@@`(
MN1H`D+D(`)3L2"*_/EGL2`(A'E;C@/+0``2YYT`&PCK*8L'6N8(``;D:`#?L
MV3N_)5FY&@`P[-D@.@56PHK*8L'6N0@`/;D:`(;L82*_/EGL80(A'E;L$SN_
M)5GL$R`Z!5:SP0`QXQ#RV``$N>=@U,(:RF+!UKF"`-FY&@`4['DBOSY9L\T`
M0^QY`B$>5N.0\N``!+D:`(W"FLIBP=:Y"`"$N>=PUKD:`):Y@@#3[`@[OR59
MN1H`'>P((#H%5NQC(K\^6;D(`!#L8P(A'E;L,3N_)5GL,2`Z!5:YYV`'XT#R
MZ``$N8(`"+D:`)"Y"`"3[#@BOSY9[#@"(1Y6XX#R\``$N><P!L)*RF+!UKF"
M``&Y&@!'[-D[OR59N1H`0.S9(#H%5L**RF+!UKD(`$VY&@"&[&$BOSY9[&$"
M(1Y6[!0[OR59[!0@.@56L\$``>,0\O@`!+GG8-/"&LIBP=:Y&@`3L\T`,+F"
M`-GL>2*_/EFY&@"-['D"(1Y6N0@`@^.0\P``!.,P\P@`!.P(.[\E6>P((#H%
M5KGG<-;"FLIBP=:Y@@#4N1H`EKD:`!WL9"*_/EFY"``0[&0"(1Y6PCK*8L'6
MN>=@![D:`#?C</,0``3L03N_)5GL02`Z!5:Y@@`([-@BOSY9N1H`D.S8`B$>
M5KD(`)2YY]"&[$D[OR59N8(`@>Q)(#H%5KD:`#C">LIBP=:Y"``TN1H`=NQA
M(K\^6>QA`B$>5NP3.[\E6>P3(#H%5K/!`#'C$/,8``2YYV!-[(DBOSY9N8(`
M2>R)`B$>5KGG@):Y@@"3PAK*8L'6N1H`';/-`-.Y&@`9[),BOSY9[),"(1Y6
MXS#S(``$N1H`=,(ZRF+!UKD(`'VYYY!([-<@OP!5N0@`->P'.[\E6;D:`#;L
M#0`Z!5:Y!`!4N0@`$+F"`%?L82"_`%6Y!`!S[!$[OR59N1H`=>P6`#H%5KD(
M`!>Y"`!KXY#PH``(YY%@``ABZ[T``@`,Y_G0``YHY_`@`#@.[+T`(1Y6N>B@
MJ^>ZD``(8N.`("``".<+T``.:.<`(!`X#L"*`````..`("``)-4'\RC@**=T
M``;K;_-@``0'_L#E___QP@<'!P<'!^MO\#``),08``!"!;D$`._C\/]@_W'C
MX/```"3C<!````*GA`!3XP`@``"4N00`@KD$`&.Y!`"2E0`@`*>$`$KL"``,
M/7Y!D)`!XP"0``"4E0"0`*=T__8;F..@<````J>$`!^Y%`"9N00`M[D$`$FY
M!``XN00`*L#E___P0.PF``D`?D$IH`"5/2``IX0`#T&PL`CCH+````*G=/_I
MN00`*NMO\-``!`?^N>EP.T&IH`'K0P`#``I00&``N00`*NMO\-``!`?^IZD`
M`*?T_^FGF```I_3_PP<'!P<'!P<'ZZ_P4``DLD\`L+D$`._KNP`@``VR3P"Q
MX_#^R/]QX^#P```DN00`HD$P\*#2!_$PL"C`Y?__\6/L)@`A`'X8$E@@\+BG
M.$``P"L``/``[",`"(!VI0^@`.P@`!-@=KD$`"JG.0`"P.7___')$!*G&O__
MB!``'Z?T``2G&```U0?Q,+`HN10`(:=T``;KK_&(``0'_L#E___Q`@<'!P<'
M!^MO\#``)+)/`*"Y!`#OZZH`(``-LD\`H>/P_L#_<>/@\```)-('\3B@*.PH
M``D`?+D$`&*5`"``IW0`"]4'\3B@**=T`(?K;_%P``0'_L#E___QQ;D$`)+L
M*/_R`'RY!``IP.7___`K["@`6@!\0;`@$Y4N(!.G=``&E0"P`:>$__"5+B`3
MIX0`5Z<9``#L1CR_`%6GA`!:ISD`#[D)`#3G`V```#>G&P`0YR``,`"!IX0`
M#.<!8`!`!J<;`!#G(``P`(&G=/_XYP(`!P`A08`P`;F$`%"Y(`!3N>(@&*<D
M`#7CX5_P_W'L2SR_`%6G&0``IX0`,J<Y``^Y"0`TYT,@$P`WIQL`$.=D0#``
M@:>$`"CG02`30`:G]/_VN00`*<#E___NC+D$`";`Y?__[L>G]/^&E2ZP`:=T
M_ZF5`+`"IX3_CZ?T_Z.G.0`/I_3_M,#E___P5*<Y``^G]/_<YP8`!P`A08`P
M`;F$`%"Y(`!3N>(@&*<D__'C(5_P_W$:XJ?J``*Y%`".N00`*,#E___N9N.P
M\*``)*<Y``*Y!`"RN00`2,!0```2T,#E___PY[D$`"M!,/"HP.7__^\@["@`
M#?]^6.#PP*<80`#`ZP``\`#LX0`/@':Y!``KP.7___!.N00`*\#E___PB:?T
M_SFY!``KP.7___\&I_3_]`<'ZV_P,``DLD\`H,`0``!`6^MJ`"``#>.P$```
M!+)/`&&Y!`#OX_#_6/]QX^#P```DXRM@```$Q$@``$!)P%```#+:P#```!*$
MP.7___"HY4CPH```XRM@```$P$````]3P&```!/=P#```!*`N00`5L#E___O
M!.MO\-@`!`?^!P?K?_`X`"2R3P"PN00`[^N[`"``#;)/`+'C\/]8_G'CX/``
M`"3C$/"@`7&Y!`"#T@<0`+`H09#PH+D$`**Y!``YITD/_\`@```27,#E___N
M=^PL`!(`?NP"__\`V!@2N10`($$R\*"5`#``IW0`(NP&`!\`?L!````_YN-0
M0```!+D$`#KC);````2Y!`!(P.7__^X5XY#PH`%QU0>0`+`HIW0`*>M_\.`!
M!`?^&!"Y%`!QN00`*;D$`$>G.0`OP.7__^Y-["C_V`!\P.```#^[XX#@```$
MN00`5^,HL```!+D$`$FY!``ZP.7__^[HI_3_T\#E___O0P<'!P<'!P<'ZV_P
M,``DLD\`<+D$`._K=P`@``VR3P!QX_#_0/]QX^#P```D0:`P`94],`#2!_"X
M<"BYXG"CIQD``+D$`++L.CR_`%6GA`!YIRD`#[D)`"/G`J```#>G&P`0YR``
M,`"!IX0`#.<!H`!`!J<;`!#G(``P`(&G=/_XYP(`!P`A05`@`;F$`$"Y(`!"
MN>(@%:<D`%3C84_P_W&Y!``KXV#PH``D03#PM,#E___]+;D$`(+L*`!+`'RG
M:0``[#(\OP!5IX0`/Z<I``^Y"0`CYT*````WIVL`$.=D0#``@:>$``SG1H``
M0`:G:P`0YV1`,`"!IW3_^.=&``<`(4$`(`&YA`#4N2``TKGB(&"G)``:XY#P
MH``$XU;?\/]Q[)4!",!EXX#PM``4Q&@``#[UZX@``P`-I_0`6*<I``^G]/^5
MIRD`#Z?T_\_$:```/N7C@&````3C$(````*GA`#?N00`Z*>8```8V:>:``%!
MX.`(XS#@```"IW3_^*?:``.Y%``=ZS$``P`-XS#PJ``DP"```#]"XQ`@```2
MIX0`EN,P\*@`!+D$`"C`Y?__[8GC(&```"2Y!`#2["@`>@!\N10`6>N%``,`
M#5"0\+2GF@`!N10`F>OI``,`#4$>T`#E2!````#C$+```)2Y!`#KE0"P`*=T
M``VG]`"-0>#@`>,0X```E)4`X`"GA``%[!;_]SU^N0D`Z[D4`#[C(/"@``2Y
M!`#802(P`N/08```",#E___L5N,@T```).PH`#D`?.-`8```!.,`L```D.-8
M0```!$&0L`%"`%``&(#L!@`0`'RG]``NXV"0``"009"0`4)@L`$8ANQH`"0`
M?$*`\*"Y!`"UE3WPH$%04`&G=/_MDCVP`*?I``#C'J```)!"'K`!I^L``>P6
M__D`?-4'\+AP**=T`#KK;_#P``0'_KD$`+6G]/_GXR#PJ``$P$```#ZCY4Q`
M```!P.7__^P!N00`TNPH_^4`?.-0\*@`!+D4``FY!``XZX```P`-N00`2,#E
M___NG>/08```)*?T_UZG.0``I_3_@^5(\*@`$*>8``"G]/\VP.7__^VJISD`
M`.,CH```D$(C@`"G.P`![";_^0!\I_3_M`<'!P<'!P<'!P>R3P`@P!```#WV
MZU(`(``-XS`0```$LD\`4<1(```][^,C4```!,!0```P?<`P```0)\#T___N
M2P<'!P<'!P<'ZV_P,``DLD\`D+D$`._KF0`@``VR3P"1X_#_2/UQX^#P```D
MXQ#PL`)QX[#PKP%QT@<0`)`HP.7__^T9P````!`FXP#PH``DN00`8J=)$`&G
M.0`"N00`*\!0```0$D&`\*[`Y?__[@.Y!``KN00`.*=)$`#`Y?__[!KL)``Q
M`'[L<@`!`-BY!`!BN10`=[D$`"?`Y?__ZUNY!`"B["@`$@!\N10`MKD$`%>Y
M!``XN00`2\#E___KRT$KH`"2`"``XS#PL`)QU0<P`)`HIW0`#+D$`"KK;_#H
M`@0'_J>I``"G]/_PP.7__^T"!P<'!P<'P/3___^(!P<'!P<'!P<'!^MO\#``
M)+)/`-"Y!`#OZ]T`(``-LD\`T>/P_K#^<>/@\```).,0\4@!<;D$`*+2!Q``
MT"BY!`"3P"````^K03#PM,#E___[%Z<Y`"^Y!`"RN00`*L#E___LVNPH`!D`
M?,`@```/G+D$`#K`Y?___8.Y!``JXW#Q2`%QU0=P`-`HIW0!F.MO\8`!!`?^
MN00`*<#E___KW,`P```/B,#E___K)KD$`&+L*/_=`'SLBCR_`%5!D/%(07#P
MN)4`8`"GA`"V[+@`#P!\IP@``+D$`#:Y!``KLET`,J<4__ZGA`"6ITD``.P&
M/+\`5:>$`2:G60`/N0D`4.<%8```-Z=+`!#G(``P`(&GA``,YP1@`$`&ITL`
M$.<@`#``@:=T__CGX@`'`"%!,%`!N80`'KD@`!6YXB!#IR0!`>/D'_#_<>->
M;___<>QE`'^@9;GI8"6G(0`!IX0`#I4O4`"G=`#RD@!0`.-07___<>QE`!F`
M9.M"``$`#)4O4`"G=`#CD@!0`.LO7___5:=T`-SK`%___U+C4%_^_W&G1__O
MIVD``.Q%/+\`5:>$`0*GZ0`/N0D`Y.<>4```-Z=K`!#G,1`P`(&GA``,YQ90
M`$`&IVL`$.<Q$#``@:=T__CG`P`'`"%!,.`!N80`$+D@`!ZYXB!CIR0`W>/F
M'_#_<;D$`&6G]``CE0"P`:=T`!K`,```#L^G*0``P.7__^IKN00`8NPH_R(`
M?)4`8`"G=/].[+@`!P!\E2ZP`*>$_^:GZ0`!P&````ZHIUD``.R(`'0`?*<I
M``^Y"0`HYU*@```WIUL`$.=U4#``@:>$``SG5:``0`:G6P`0YW50,`"!IW3_
M^.='``<`(4$`(`&YA``4N2``$KGB(%"G)`!.XS4?\/]QIUD/_T'CX`'LY?[>
M(&7CH/"H`"3`0```#GSC0/"@`"2G.0`"N00`*<!0```.Z:=)$`#`Y?__[$VY
M!``WN00`*<#E___JANPF_Y,`?EA@\-"E+X``P&L``/``[&+_B6!VN00`*:<Y
M``'`Y?__["+L)O]_`'ZY!``YP"````Y"P.7___PKN00`*<#E___JDJ?T_J6G
M*0`/I_3_FZ=9``^G]/[HIUD``.P&/+\`5:>$`"RGZ0`/N0D`X.=.8```-Z=;
M`!#G9$`P`(&GA``,YT5@`$`&IUL`$.=D0#``@:=T__CG%@`'`"%!(.`!N80`
M,;D@`#ZYXB!2IR0`!^/E/_#_<:?T_U.GZ0`/I_3_XJ?I``^G]/\,P.7__^L<
M!P<'!P<'!P<'!^N_\%@`)+D$`._C\/]@_W'CX/```"2Y!`"RISD`+\#E___K
MI4$0(`&Y`@`BN00`*[GB<"'KO_#X``3`]/__ZB?KG_!(`"2R3P"@N00`[^NJ
M`"``#;)/`*'C\/]8_G'CX/```"3C$/"@`7'2!Q``H"CL*`"9`'RY!``RE0`@
M`*>$`)*G60``[$(\OP!5IX0`AZ<I``^Y"0`DYP(P```WIUL`$.<@`#``@:>$
M``SG!3``0`:G6P`0YR``,`"!IW3_^.<"``<`(4&P(`&YA`"0N2``DKGB(%NG
M)`!BXY6?\/]QI^D0`.Q)``$`V>Q.`&T@94&P\*"Y!``KP.7__^NXXQF___]Q
M[!L`*\!EN>FP,:<1``&GA``.E2\0`*=T`""2`!``XQ`?__]Q[!L`&8!DZU,`
M`0`,E2\0`*=T`!&2`!``ZR\?__]5IW0`"NL`'___4N,0'_[_<:=7_^^Y!``K
MISD`+\#E___K`^PH`!T`?.PK``7`99(`(`"Y!``KP.7__^F&XT#PH`%QU0=`
M`*`HIW0`'^N?\/`!!`?^IRD`#Z?T_X?C(/"@`7'5!R``H"BG=``/P"````T-
MZY_P\`$$P/3__^EEIRD``*?T_]W`Y?__ZBX'!P<'!P<'!P<'!P<'!^NO\%``
M)+)/`*"Y!`#OZZH`(``-LD\`H>/P_U#_<>/@\```)$&P\*32!_"HH"BY!``[
MP"````SLP.7___A,["@`+@!\Q$@``#I.XR#PI``4ZQ(``P`-XQ!````(XU`0
M"``$XU`0```D[%C_XP!\XP`0$``$01`0".,`$```).P&__@`?+D$`#O`(```
M#,'`Y?__^"'L)O_8`'RY!``[P"````R[P.7___@6["@`+@!\Q%@``#H8XQ#P
MI``4Z^$``P`-X^!0```(XP#@"``$XP#@```D[`C_XP!\XS#@$``$0>#@".,P
MX```).PV__@`?+D$`#O`(```#)#`Y?__]^OL)O_8`'RY!``[P"````R)P.7_
M__?@["@`+@!\Q%@``#GBX^#PI``4ZTX``P`-XT!0```(XS!`"``$XS!````D
M[#C_XP!\XR!`$``$04!`".,@0```).PF__@`?+D$`#O`(```#%[`Y?__][7L
M)O_8`'RY!``[P"````Q8P.7___>J["@`+@!\Q#@``#FLXR#PI``4ZQ(``P`-
MXQ`P```(XT`0"``$XT`0```D[$C_XP!\XP`0$``$01`0".,`$```).P&__@`
M?+D$`#O`(```#"W`Y?__]W_L)O_8`'RY!``[P"````PFP.7___=T["@`+@!\
MQ$@``#EVXQ#PI``4ZU$``P`-XU!````(XP!0"``$XP!0```D[`C_XP!\X^!0
M$``$05!0"./@4```).SF__@`?+D$`#O`(```"_O`Y?__]TGL)O_8`'RY!``[
MP"````OXP.7___<^["@`+@!\Q$@``#E`XU#PI``4ZS4``P`-XS!````(X^`P
M"``$X^`P```D[.C_XP!\XR`P$``$03`P".,@,```).PF__@`?+D$`#O`(```
M"\W`Y?__]Q/L)O_8`'RY!``[P"````N:P.7___<(["@`+@!\Q.@``#D*XR#P
MI``4ZQ(``P`-XQ#@```(XS`0"``$XS`0```D[#C_XP!\XP`0$``$01`0".,`
M$```).P&__@`?+D$`#O`(```"V_`Y?__]MWL)O_8`'RY!``[P"````N2P.7_
M__;2["@`+@!\Q#@``#C4XQ#PI``4ZT$``P`-XT`P```(XP!`"``$XP!````D
M[`C_XP!\XU!`$``$04!`".-00```).Q6__@`?+D$`#O`(```"V?`Y?__]J?L
M)O_8`'RY!``[P"````MAP.7___:<["@`+@!\Q#@``#B>XT#PI``4Z^0``P`-
MX^`P```(XU#@"``$XU#@```D[%C_XP!\XR#@$``$0>#@".,@X```).PF__@`
M?+D$`#O`(```"S;`Y?__]G'L)O_8`'RY!``[P"````LPP.7___9F["@`+@!\
MQ%@``#AHX^#PI``4ZQX``P`-XQ!0```(XR`0"``$XR`0```D["C_XP!\XP`0
M$``$01`0".,`$```).P&__@`?+D$`#O`(```"P7`Y?__]COL)O_8`'RY!``[
MP"````K'P.7___8P["@`+@!\Q"@``#@RXQ#PI``4ZS$``P`-XS`@```(XP`P
M"``$XP`P```D[`C_XP!\XT`P$``$03`P".-`,```).Q&__@`?+D$`#O`(```
M"IS`Y?__]@7L)O_8`'RY!``[P"````K)P.7___7ZN00`,NPH``D`?,`@```*
MM,#E___X;[D$`#O`(```"K_`Y?__]>>Y!``R["@`"0!\P"````J]P.7___A<
MN00`.\`@```*N\#E___UU+D$`#+L*``:`'S`(```"EO`Y?__^$G5!_"HH"BG
M=``CP#````JVP"````IMZZ_Q```$P/3___@XN00`.\`@```*G\#E___UL+D$
M`#+L*/_E`'S`(```"F7`Y?__^"6G]/_<P.7__^=<!P<'!P<'!P<'!^N_\%@`
M)+)/`+"Y!`#OZ[L`(``-LD\`L>/P_U#_<>/@\```)$$P\*3`(```"D'2!_"H
ML"C`Y?__]7[L*``@`'Q#$"``&"'`)P```#"YA``"N0,`,*<1`/_K0P`_``SL
M2````$+5!_"HL"BY%``DIW0`"NN_\0@`!`?^IT@``*?T__/`Y?__YQ,'!P<'
M!P<'!V``\(!@(/"(8$#PD&!@\)CK/_`8`"3$&```-WVR3P``N00`[^/P_SC_
M<>/@\```)+D$`$+K,``@``WC(!````2R3P`Q0>#PR-('\,`P*./@\+@`).5(
M\*```>5(\*@``$%0\*!!8/%HXV#PL``DISD``L#E___FHZ<I`/_`Y?__YEX'
M!P<'!P<'!P<'!P<'!^M_\#@`)+)/`)"Y!`#OZYD`(``-LD\`D>/P_U#O<>/@
M\```).,0\*@0<:<Y``#2!Q``D"BY!`!RITD``L#E___D]L`Q__\``.RB__\`
MV>P*,(``5;D$`""G"___N8$``Z<+``&Y`@"JN>*@`KD)`*#LI`"2`'Q!L/"@
MP(```#<3N00`.KD$`">G20``P.7__^3.["@`F_]\N00`.[D$`"?`00`!``C`
MY?__YM'L*`"(_WZY%`!"[$P`9@=]XQ2_^/]Q[!L`8$!EXU"````$[.$^OP!5
MXU`0```@IX0`:^,0'___<>P;`$]`9>SH`"0`?.SH`!8!?.SH``L"?.-0$```
M(*>$`%?C$!___W'5!X``$`"GA`!/XQ`?__]QU0>``!``IX0`1^,0'___<>P;
M`"M`9>,`@```!.,`$```(*>$`#GC(!___W&Y!``2XP`@```@IX0`+^,0+___
M<>,`$```(*>$`"?C$"_^_W'C`"_^_R"GA``?XQ`O_?]Q[!O_VZ!EPJ0``0``
MP#'__P``[*/_>6!DIRG__^-P\*@0<=4'<`"0**=T`!CK?_#H$`0'_KGIL"&Y
M"``JI_3_\,`@```))\#E___^U\`@```)&L#E___^T<#E___EV@<'!P<'!^OO
M\'``)+D$`._C\/]@_W'CX/```"3`Y?__X[G`Y?__XY;L*``&`'SC("````3K
M[_$0``0'_@<'!P<'!P<'!P?K;_`P`"2R3P"@N00`[^NJ`"``#;)/`*'C\/]`
M_W'CX/```"2Y!`!B03#PM-('\+B@*,`@```(XL#E___SW.PH``D`?+D$`+*5
M`"``IW0`$M4'\+B@**=T`%JY!``VP"````C,ZV_P\``$P/3___9#IQD``.PV
M/+\`5:>$`$2G*0`/N0D`(^<"8```-Z<;`!#G(``P`(&GA``,YP%@`$`&IQL`
M$.<@`#``@:=T__CG`@`'`"%!4"`!N80`0+D@`$*YXB`5IR0`'^.13_#_<:?I
M``#L&SR_`%6GA``<IRD`#[D)`"'G0K```#>GZP`0YV1`,`"!IX0`$N=.L`!`
M!J?T__:G*0`/I_3_RL#E___E+Z<I``^G]/_RYS8`!P`A00`@`;F$`$.Y(`!"
MN>(@X*<D__'C7D_P_W%!F5`"N00`*<#E___C1..P\*@`),"P```'[>.P\*``
M)+D$`$G`4```"%VY!`"2ISD``L#E___EO]4'\+B@**=T_\JY!``YP"````@\
MZV_P\``$P/3___6SZV_P,``DLD\`$+D$`._C\/XH_W'CX/```"2GZ__X8(#@
M`.LQ`"``#;)/`#'`0```-6+C,/#``"32!_'(,"A!@/#,N00`TKD$`#C21_#P
M0!#2#_#80%C2!_#H0&C`(```!Y'`Y?__\O_L*``)`'RY!`"RE0`@`*=T`7W`
MY?__XI_`Y?__XGSL*``X`'SCH"````*GA``RI^D``.P*/+\`5:>$`">G*0`/
MN0D`(.<"H```-Z?K`!#G(``P`(&GA``,YPZ@`$`&I^L`$.<@`#``@:=T__CG
M4@`'`"%!8"`!N80`5;D@`%*YXB#FI\0!)Z<I``^G]/_G07#PV.,@<````J>$
M`!6Y!``XP.7___*L["@`!P!\E0`@`*=T`-JG>P`(XR!P```"IW3_[Z<I``VG
M>0`-P.7__^*#I[D`#;D$`)*SP0""P*````>9IQ@`4[D$`$NY!``IN18`8:<Y
M``+`4```!Y#`Y?__Y/JY(0![N00`.[GBH#>YZ;`3IQL``KDA`!.YXE`3N0D`
MLT&@H`'CNQ_^_W%!D)`"XQ"@``"4E0"@`*=T_]9!D/$0P"````<YI_0`":>;
M``CC()_X_P*GA``@N00`.,#E___R3;D$`*+L*/_R`'R5`"``IX3_[<#E___R
ML>PH_^@`?KD$`"K`Y?__XR6Y!`!B["8`'0!\07#P\.-@<````J>$`!65`&``
MIX0`X+D$`";`Y?__\I3L)@#"`'ZG>P`(XV!P```"IW3_[Z?I``#L1CR_`%6G
MA`#&IRD`#[D)`"3G$F```#>GZP`0YS$0,`"!IX0`#.<>8`!`!J?K`!#G,1`P
M`(&G=/_XYP,`!P`A03`@`;F$`%"Y(`!2N>(@XZ<D`*&SS0"8X[Y?\/]QIQD`
M`.RI/+\`5:>$`Q"GZ0`/N0D`ZN=>D```-Z<;`!#G=5`P`(&GA`"6L\T`2.=1
M0`!`!J?T__3`Y?__XK:G>P`(N00`HNPH_Q``?*?I``#L0CR_`%6GA`!8IRD`
M#[D)`"3G0J```#>GZP`0YV1`,`"!IX0`#.=.H`!`!J?K`!#G9$`P`(&G=/_X
MYP8`!P`A06`@`;F$`%"Y(`!2N>(@YJ<D`#/C?E_P_W'KMP`!``VGNP`!N00`
M*\#E___A=N,0H```E+D$`)*5`*``IX0`/+D$`'NSP0""I_3^\<#E___]@.-`
M\,``!-4'\<A`**=T`"]H@/'0N00`*^MO\@@`!,#T___B4J<I``^G]/^VN00`
M)J=[``C`Y?__XD>Y!`!B["C_)P!\I^D``.Q&/+\`5:=T_SZG*0`/I_3_2*=I
M``"G]/\OL\$`@J?T_N7`Y?__XOSG)P`'`"%!`.`!N80`4KD@`%ZYXB`0IR0"
M8>,Q7_#_<1H[ISH$!+D4`'.Y!``GP.7__^$28(#PL,`0```%O>,0\*``),"P
M```&,N.P\*@`)+D$`)*G.0`"N00`1\!0```&(<#E___CB+D$`"FG.0'`P.7_
M_^)Q["8`"_]^P.7__^([6&`@`.QF`5P1?D&@\3BSP0"*N00`*;D$`#K`Y?__
MXML8LNPF``T`?EC@\5"G2$``P.L``/``[.0`*(!VQ(@``#,6XU#0```$XR"`
M```$N00`:<!````&"Z<Y``+`Y?__XJJGJ0``XS#PP``$U0?QR#`HIW3_@[D$
M`"IH@/'0ZV_R"``$!_Y88/%4P.7__^!C[&+_UF!V6%#Q4*<H`<#`6P```?_L
M4O_,8':Y!``GP.7__^"1N00`.+D$`*+`(```!@#`Y?__\)NY!``R["@`Z@!\
MXR#0```$P.7___58N00`8NPH`-\`?*<9``#L!CR_`%6GA`#AI^D`#[D)`.#G
M#F``"#>G&P`0YR``,`Z!IX0`#.<!8`!(!J<;`!#G(``P#H&G=/_XYS(`!P0A
M05#@`;F$`$.Y(`!.N>(@%:<D`+SC(4_P_W'L+``@`WZY%``2P.````6YXS%O
M_/]QIP@``+)=`..G%/_^IW0`#^PH`2H$?J<J__NY%`!"051@`)4O4`"GA`$?
MN00`.,`@```$],#E___P-.PH`*T`?..`(```E.R(`*<`?NR(`*0P?L`P```%
M&L`@```$W\#E___RG\#E___AF.,@\*@`),`````%X^,`\+``),`P```$K.,P
M\*``)+D$`&FY!`!'N00`*L!0```%?:<Y``+`Y?__XGNG]``RP.7__^$V6$`@
M`*=.`!&G=``SP.7__^%MXR#PJ``DI[H``<`0```%MN,0\+@`)+D4`%OC4/"P
M`"3`@```!'KC@/"@`"2Y!`!IN00`1[D$`"K`4```!5*G.0`"P.7__^))N00`
M*J<Y`<#`Y?__X3+L*/_)_WZY!``IP.7__^'ZN00`.L`@```$2,#E___R-KD$
M`"K`Y?__^[FG]/[EXV#0```$IQD``.P&/+\`5:=T_R.GZ0`/I_3_+<0H```Q
MUKD4`&;C8/"@`"3C4-````3C("````2Y!`!IP$````2HISD``L#E___A9:?T
M_KNY!``FISD``,#E___AS+D$`-+L*/]6`'[`Y?__^G"Y!`!B["3_3@!\ITD`
M`.,P;_;_<;D$`"W`Y?__WW6Y!``M03#PTJ=)``;`Y?__X7SL)@"0!GS`X```
M)!?5!>``\-*G=/\OXS!OSO]QITD``+D$`"W`Y?__WU>SS0`XN00`+:=)`"C`
MY?__X5[L)@!R*'Q@@/"HD@#Q8,#0```%!>/0\+``),#@```#SN/@\*``)+D$
M`$>Y!`!IN00`*L!0```$EZ<Y``+`Y?__X9VG]/]>X]#0"``"IX3^X*<I``#L
M#3R_`%6GA``]IQD`#[D)`!#G0=``"#>G*P`0YV1`,`Z!IX0`#.="T`!(!J<K
M`!#G9$`P#H&G=/_XY^8`!P0A03`0`;F$`$ZY(`!!N>(@(Z<D`!CC4D_P_W'L
M7/ZO`WWC%=_\_W'`(```!$JG"```LET`(:<4__ZYXH!MI_3^GJ<9``^G]/_1
MI^D`#Z?T_/[`(```!#C`Y?__^7H'!P<'!P<'!P<'!P<'!^M_\#@`)+)/`+#`
MH```,-OKNP`@``WC$*````2R3P"QN00`[^/P_U#_<>/@\```)-('\*BP*..1
ML```!$&`\*3`(````T_2`)"QD+"Y!``XP.7__^Z8["@`!P!\E3$@`*>$`-+`
MY?__]B;C(*````3CDK````2Y!``IIUD``Z=)``'`,```!`C`Y?__WLBY!`"2
M["@`'P!\XS`@$``$XW"@```$XS`P```$XR>P```$P$````/RP.7__][!XT"0
M$``$XS!````$D4`P#:=T`*_C<*````2G60`#XR>P```$ITD``<`P```#V\#E
M___>E[D$`)+L*``<`'RY!``XP"````+5P.7__^X^XU"0$``$N00`0N,P4```
M!.PH`'L`?.,GL```!,#E___>B>.@H```!*=)``'C>K````3`,````["Y!``G
MP.7__]W9P$````.SN00`,KD$`"?`Y?__WF_C&K````2Y!``XD@`0L<`@```"
MF,#E___N!L0K```PD[D$`(+L*``L`'RY!``HISD!P,#E___?8^P"``$`V.P,
M`!8!?^PH`!,1?L2X```P=[D$`%+C,+````2Y!`!(P"````..P.7__]_JU0?P
MJ+`HIW0`->M_\.@`!`?^Q"@``#!>P.7___J?Q"L``#!<N00`@NPF_\P`?,`@
M```#8,#E___?S94`(`&GA/\WI_3_+,3H```P1+D$`"/C,.````3`Y?__[["G
M]/^#XR>P```$P.7__]]4I_3_3<#E___?7^N?\$@`)+)/`*"Y!`#OZZH`(``-
MLD\`H>/P_U#_<>/@\```)+D$`+)!,/"DT@?PJ*`HP"````)$P.7__^V$["@`
M$P!\XQ`@``"4[!@`#0!^[!@`"C!^[+@`!P!\E0"P`*=T``O5!_"HH"BG=``U
MZY_P^``$!_ZY!``KP.7___0KISD`+[D$`)+`Y?__W[BY`@`B00`@`;D$`"FY
MXG`@P.7__]X]ITD`!,`P```"8\#E___=Q>PF_]@`?M4'\*B@**=T``JY!``K
MZY_P^``$P/3__^WYP.7__][R!P<'!P<'Z]_P:``DP-```"')N00`[^/P_V#_
M<>/@\```)*<I`(#`Y?__W0SG`-`@,`;G(-`0,`;G0-``,`;G`"``,`[G("`0
M,`[G0"`@,`[E2"`P``#E3"!X``#KW_$(``0'_@<'ZV_P,``DN00`[^/P_UC_
M<>/@\```)*?K__A@@.``N00`DNL4``,`#>-0("@`!.L$`!T`#+D(`!7L(2"_
M`%6Y,0!1N00`A.,`D#``B+D$`-/G`@```&+C8)!X`!+G`)`H,`ZG=`!'07"0
M..R,`#(_?NMH``8`WKD$`*WLYB"Y!EFG:O__I^O_P+D6`%;KO@`&``RSP0"%
MI[L``=(_<`"@`+D$`"E!H*!`P.7__^%\I[?_]K/-`!BGBO_`B6``!NLA``8`
M#1N&0=+00+D4`(BY!``]N00`)[D$`$C`Y?__WV]0@)!X:(#PH.MO\-@`!`?^
MI[@`0!NV&;1!<)`XN?(PM+D$`">Y&``FN10`J[D$`$K`Y?__WU08.UHPD'A0
M,)!X[#;_XD!^N?FP2+D$`"FY"`#:N10`A,#E___A-:?T_Y?KC_!``"3`T```
M(1&Y!`#OX_#_8/]QX^#P```DXY`P*``$N00`L^.`,#``!.P9.K\]6;D4`#%!
M0[`XDH!``*<:``&Y!`"BN10`(4$RL#CL'`!D.'ZG2`!`N?D0).Q!``N`=N<`
M````1*<J___G`C```#^Y!``KP.7__^#UUS>P.+`X:"#0`.L8`!@`#.LX`!``
M#.L(``@`#.M9`!@`#.OI``@`#.<A````(N<C``$`(N<@``(`(N<H``,`(NN)
M`!``#.<E``0`(N<H``4`(N<N``8`(N<I``<`(F`@L'"Y!``KP.7__^"_T@.@
M`+`$N00`*](#H`2P#-(#H`BP%-(#H`RP'-(#H!"P).N/\.``!,#T___>%*<(
M`#BY^1!0[`'_LH!VIUK__[D6`.7&X`````6G]/^HUP`P`#``!P<'!\18```N
M!,#T___;N0<'!P?K;_`P`"3C$/!X``2G^_]@XQ#P```DP,```"S1XT#Q$``$
MZV_PT``$!_0``````````@`!)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4```O<')O8R]S96QF+V5X90``
M+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O
M`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#
M04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)4@!005)?
M5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``,0!L
M<V5E:R!F86EL960``')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-4
M14T``"4P,G@``"5S)7,E<R5S``!P87(M```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(``!P87)L
M```N<&%R``!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S```8`'!E<FP``#``4$%2.CI086-K97(Z
M.E9%4E-)3TX``#$N,#8S`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M90``+2T``&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH`55-%4@``55-%4DY!344``%1%35!$25(`5$U0`"]T;7``
M`````````,/2X?````````````````"8NMS^`````!`R5'8`````9T4C`0``
M``#OS:N)``````````!P97)L>'-I+F,``$-!0TA%```````````!&P,[````
M[````!S__WQ8```&#/__?N@```$(__^`&````3C__Y9X```!>/__EU@```'(
M__^7^````?C__YGX```"-/__FG@```)P__^;>````JS__Y[(```"[/__GP@`
M``,`__^?^````SS__Z`(```#4/__H\@```.,__^D"````[C__Z6H```#_/__
MJT@```0P__^KV```!&#__ZQH```$C/__KD@```3(__^NB```!.C__[`8```%
M-/__N/@```6,__^[.```!<C__[P8```&3/__O'@```9P__^]N```!K#__[[X
M```&Z``````````4``````%Z4@`!>`X!&PP/H`$'#@`````4````'/__?=@`
M``!"```````````````4``````%Z4@`!>`X!&PP/H`$````````\````'/__
M?M@``!9:`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4X.T`<#%CX*S\[-S,O*R<C'
MQ@Z@`4(+````````3````%S__Y3X````V`!,A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5*#L`"`I(*S\[-S,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@L`````
M```L````K/__E8@```":`$:*"HL)C`B-!XX&CP58#M@#`G0*S\[-S,O*#J`!
M0@L````X````W/__E?@```'^`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.X`-N
M"L_.S<S+RLG(Q\8.H`%""P`````X```!&/__E[P```!^`$:&#H<-B`R)"XH*
MBPF,"(T'C@:/!60.R`("4L_.S<S+RLG(Q\8.H`$````````X```!5/__F```
M``#X`$:'#8@,B0N*"HL)C`B-!XX&CP58#L@B`HP*S\[-S,O*R<C'#J`!0@L`
M```````\```!D/__F,0```-&`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.X`(#
M`IP*S\[-S,O*R<C'Q@Z@`4(+````````$````=#__YO4````.``````````X
M```!Y/__G`````#J`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.V$("O`K/SLW,
MR\K)R,?&#J`!0@L````0```"(/__G+0````&`````````#@```(T__^<L```
M`[8`1H8.APV(#(D+B@J+"8P(C0>.!H\%6`[P(P)L"L_.S<S+RLG(Q\8.H`%"
M"P```"@```)P__^@-````$``1HL)C`B-!XX&CP5*#L`":L_.S<S+#J`!````
M````0````IS__Z!(```!D@!&B0N*"HL)C`B-!XX&CP58#L@B`P$Z"L_.S<S+
MRLD.H`%""V0*S\[-S,O*R0Z@`48+```````P```"X/__H:0```66`$:*"HL)
MC`B-!XX&CP58#M`"`P5""L_.S<S+R@Z@`48+````````+````Q3__Z<0````
MB`!&BPF,"(T'C@:/!5@.T`("6@K/SLW,RPZ@`4(+````````*````T3__Z=P
M````@@!@A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#N@"```````X```#</__I]0`
M``':`$:'#8@,B0N*"HL)C`B-!XX&CP58#M""!`,!D`K/SLW,R\K)R,<.H`%"
M"P`````<```#K/__J7@````V`$:.!H\%2@[``F3/S@Z@`0```$@```/,__^I
MF````9``1H8.APV(#(D+B@J+"8P(C0>.!H\%6`[@`@),"L_.S<S+RLG(Q\8.
MH`%&"P,!&L_.S<S+RLG(Q\8.H`$```!4```$&/__JMP```C2`$J&#H<-B`R)
M"XH*BPF,"(T'C@:/!4H.^`1.F!4#`W(*S\[-S,O*R<C'QM@.H`%&"P,!4@K/
MSLW,R\K)R,?&V`Z@`4(+````````.```!'#__[-D```"0`!&APV(#(D+B@J+
M"8P(C0>.!H\%9`[0`@,!L`K/SLW,R\K)R,<.H`%""P``````0```!*S__[5H
M````V@!&B0N*"HL)C`B-!XX&CP58#M`"`E8*S\[-S,O*R0Z@`4(+`E@*S\[-
MS,O*R0Z@`48+```````\```$\/__=D0```*0`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!5@.Z`(#`;X*S\[-S,O*R<C'Q@Z@`4(+````````(```!3#__[7$````
M7@!&C0>.!H\%4`[``@)&S\[-#J`!````/```!53__[8````!0`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5*#L@"3I@5`M`*S\[-S,O*R<C'QM@.H`%""P```#0`
M``64__^W`````3P`1H@,B0N*"HL)C`B-!XX&CP50#L`"`OH*S\[-S,O*R<@.
MH`%&"P``````$```!<S__[@(````#```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```E$````````"3```````````$````````"V@`````````!`````````NH`
M````````#````````!HX``````````T```````!D$``````````9````````
MN[@`````````&P`````````(`````````!H```````"[P``````````<````
M``````@`````;__^]0````````-X``````````4````````-$``````````&
M````````!%@`````````"@````````1F``````````L`````````&```````
M```5`````````````````````P```````+W(``````````(````````%$```
M```````4``````````<`````````%P```````!4H``````````<````````2
MH``````````(`````````H@`````````"0`````````8`````````!X`````
M````"`````!O___[``````@```$`````;____@```````!(P`````&____\`
M`````````0````!O___P````````$78`````;___^0`````````0````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"[R```````````
M```````````````````:I@```````!K&````````&N8````````;!@``````
M`!LF````````&T8````````;9@```````!N&````````&Z8````````;Q@``
M`````!OF````````'`8````````<)@```````!Q&````````'&8````````<
MA@```````!RF````````',8````````<Y@```````!T&````````'28`````
M```=1@```````!UF````````'88````````=I@```````!W&````````'>8`
M```````>!@```````!XF````````'D8````````>9@```````!Z&````````
M'J8````````>Q@```````![F````````'P8````````?)@```````!]&````
M````'V8````````?A@```````!^F````````'\8````````?Y@```````"`&
M````````("8````````@1@```````"!F````````((8````````@I@``````
M`"#&````````(.8````````A!@```````"$F````````(48`````````````
M``````````````````````````!>````````````````````````````````
M````````````````````````````````````````````````````P(``````
M`````````````"%@``````````````````#`"`I005(N<&T*````````````
M``````"DL````````&2<``````````````````!E/````````&5`````````
MI*0```````!DH@```````*2L``````````````````"DE````````*2:````
M``````````````!G)$=#0SH@*%5B=6YT=2`Q-"XR+C`M-W5B=6YT=3$I(#$T
M+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN
M;W1E+G!A8VMA9V4`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0`````````"`````````C@````````".``````````/
M`````````````````````0``````````````$P````<``````````@``````
M``)(`````````D@`````````)`````````````````````0`````````````
M`"8````'``````````(````````";`````````)L`````````.P`````````
M```````````$```````````````T````!P`````````"`````````U@`````
M```#6``````````@````````````````````!```````````````0F____8`
M`````````@````````-X`````````W@`````````W`````8`````````````
M``@``````````````$P````+``````````(````````$6`````````18````
M````"+@````'`````@`````````(`````````!@```!4`````P`````````"
M````````#1`````````-$`````````1F`````````````````````0``````
M````````7&____\``````````@```````!%V````````$78`````````N@``
M``8```````````````(``````````@```&EO___^``````````(````````2
M,````````!(P`````````'`````'`````0`````````(``````````````!X
M````!``````````"````````$J`````````2H`````````*(````!@``````
M````````"``````````8````@@````0`````````0@```````!4H````````
M%2@````````%$`````8````6``````````@`````````&````(P````!````
M``````8````````:.````````!HX`````````#X````````````````````$
M``````````````"'`````0`````````&````````&G@````````:>```````
M``;@````````````````````!``````````@````D@````$`````````!@``
M`````"%@````````(6````````!"L````````````````````!``````````
M`````)@````!``````````8```````!D$````````&00`````````"H`````
M```````````````$``````````````">`````0`````````"````````9$``
M``````!D0````````$#(````````````````````"```````````````I@``
M``$``````````@```````*4(````````I0@`````````[```````````````
M``````0``````````````+0````!``````````(```````"E^````````*7X
M````````!A`````````````````````(``````````````"^````#@``````
M```#````````N[@```````"[N``````````(````````````````````"```
M```````(````R@````\``````````P```````+O`````````N\``````````
M"`````````````````````@`````````"````-8````&``````````,`````
M``"[R````````+O(`````````@`````'```````````````(`````````!``
M``#?`````0`````````#````````O<@```````"]R`````````(X````````
M````````````"``````````(````Y`````$``````````P```````,``````
M````P```````````B`````````````````````@``````````````.H````(
M``````````,```````#`B````````,"(`````````"@`````````````````
M```(``````````````#O`````0`````````P``````````````````#`B```
M```````E`````````````````````0`````````!`````0````,`````````
M````````````````````P*T`````````^`````````````````````$`````
$````````
